
From: Stephen Rothwell <sfr@canb.auug.org.au>

The iommu_table_cb structure is iSeries specific, so move it to the header
file that declares the function we pass it to.  vio_tce_table and
iommu_setup_iSeries no longer exist, so remove their declarations.

Signed-off-by: Stephen Rothwell <sfr@canb.auug.org.au>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 include/asm-ppc64/iSeries/HvCallXm.h |   17 +++++++++++++++++
 include/asm-ppc64/iommu.h            |   21 ---------------------
 2 files changed, 17 insertions(+), 21 deletions(-)

diff -puN include/asm-ppc64/iommu.h~ppc64-iseries-iommuh-cleanups include/asm-ppc64/iommu.h
--- 25/include/asm-ppc64/iommu.h~ppc64-iseries-iommuh-cleanups	2005-06-05 23:56:46.000000000 -0700
+++ 25-akpm/include/asm-ppc64/iommu.h	2005-06-05 23:56:46.000000000 -0700
@@ -82,24 +82,6 @@ struct iommu_table {
 	unsigned long *it_map;       /* A simple allocation bitmap for now */
 };
 
-#ifdef CONFIG_PPC_ISERIES
-struct iommu_table_cb {
-	unsigned long	itc_busno;	/* Bus number for this tce table */
-	unsigned long	itc_start;	/* Will be NULL for secondary */
-	unsigned long	itc_totalsize;	/* Size (in pages) of whole table */
-	unsigned long	itc_offset;	/* Index into real tce table of the
-					   start of our section */
-	unsigned long	itc_size;	/* Size (in pages) of our section */
-	unsigned long	itc_index;	/* Index of this tce table */
-	unsigned short	itc_maxtables;	/* Max num of tables for partition */
-	unsigned char	itc_virtbus;	/* Flag to indicate virtual bus */
- 	unsigned char	itc_slotno;	/* IOA Tce Slot Index */
- 	unsigned char	itc_rsvd[4];
-};
-
-extern struct iommu_table vio_tce_table;      /* Tce table for virtual bus */
-#endif /* CONFIG_PPC_ISERIES */
-
 struct scatterlist;
 
 #ifdef CONFIG_PPC_MULTIPLATFORM
@@ -122,9 +104,6 @@ extern void iommu_devnode_init_pSeries(s
 
 #ifdef CONFIG_PPC_ISERIES
 
-/* Walks all buses and creates iommu tables */
-extern void iommu_setup_iSeries(void);
-
 /* Initializes tables for bio buses */
 extern void __init iommu_vio_init(void);
 
diff -puN include/asm-ppc64/iSeries/HvCallXm.h~ppc64-iseries-iommuh-cleanups include/asm-ppc64/iSeries/HvCallXm.h
--- 25/include/asm-ppc64/iSeries/HvCallXm.h~ppc64-iseries-iommuh-cleanups	2005-06-05 23:56:46.000000000 -0700
+++ 25-akpm/include/asm-ppc64/iSeries/HvCallXm.h	2005-06-05 23:56:46.000000000 -0700
@@ -16,6 +16,23 @@
 #define HvCallXmSetTce			HvCallXm + 11
 #define HvCallXmSetTces			HvCallXm + 13
 
+/*
+ * Structure passed to HvCallXm_getTceTableParms
+ */
+struct iommu_table_cb {
+	unsigned long	itc_busno;	/* Bus number for this tce table */
+	unsigned long	itc_start;	/* Will be NULL for secondary */
+	unsigned long	itc_totalsize;	/* Size (in pages) of whole table */
+	unsigned long	itc_offset;	/* Index into real tce table of the
+					   start of our section */
+	unsigned long	itc_size;	/* Size (in pages) of our section */
+	unsigned long	itc_index;	/* Index of this tce table */
+	unsigned short	itc_maxtables;	/* Max num of tables for partition */
+	unsigned char	itc_virtbus;	/* Flag to indicate virtual bus */
+	unsigned char	itc_slotno;	/* IOA Tce Slot Index */
+	unsigned char	itc_rsvd[4];
+};
+
 static inline void HvCallXm_getTceTableParms(u64 cb)
 {
 	HvCall1(HvCallXmGetTceTableParms, cb);
_
